Documentation
¶
Overview ¶
Package v1alpha1 contains API Schema definitions for the azure v1alpha1 API group +kubebuilder:object:generate=true +groupName=azure.418.cloud
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // GroupVersion is group version used to register these objects GroupVersion = schema.GroupVersion{Group: "azure.418.cloud", Version: "v1alpha1"} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: GroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
Functions ¶
This section is empty.
Types ¶
type ContainerApp ¶
type ContainerApp struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec ContainerAppSpec `json:"spec,omitempty"`
Status ContainerAppStatus `json:"status,omitempty"`
}
ContainerApp is the Schema for the containerapps API
func (*ContainerApp) DeepCopy ¶
func (in *ContainerApp) DeepCopy() *ContainerApp
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ContainerApp.
func (*ContainerApp) DeepCopyInto ¶
func (in *ContainerApp) DeepCopyInto(out *ContainerApp)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ContainerApp) DeepCopyObject ¶
func (in *ContainerApp) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type ContainerAppList ¶
type ContainerAppList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []ContainerApp `json:"items"`
}
ContainerAppList contains a list of ContainerApp
func (*ContainerAppList) DeepCopy ¶
func (in *ContainerAppList) DeepCopy() *ContainerAppList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ContainerAppList.
func (*ContainerAppList) DeepCopyInto ¶
func (in *ContainerAppList) DeepCopyInto(out *ContainerAppList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ContainerAppList) DeepCopyObject ¶
func (in *ContainerAppList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type ContainerAppSpec ¶
type ContainerAppSpec struct {
//ContainerEnvironmentName name of the ContainerEnvironment where the ContainerApp is deployed
ContainerEnvironmentName string `json:"containerEnvironmentName"`
//ContainersTemplate template for the deployed containers
ContainersTemplate ContainersTemplate `json:"containersTemplate"`
//TargetPort port the container listens to
TargetPort int32 `json:"targetPort"`
}
ContainerAppSpec defines the desired state of ContainerApp
func (*ContainerAppSpec) DeepCopy ¶
func (in *ContainerAppSpec) DeepCopy() *ContainerAppSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ContainerAppSpec.
func (*ContainerAppSpec) DeepCopyInto ¶
func (in *ContainerAppSpec) DeepCopyInto(out *ContainerAppSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ContainerAppStatus ¶
type ContainerAppStatus struct {
LatestStatus string `json:"latestStatus,omitempty"`
FQDN string `json:"fqdn,omitempty"`
}
ContainerAppStatus defines the observed state of ContainerApp
func (*ContainerAppStatus) DeepCopy ¶
func (in *ContainerAppStatus) DeepCopy() *ContainerAppStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ContainerAppStatus.
func (*ContainerAppStatus) DeepCopyInto ¶
func (in *ContainerAppStatus) DeepCopyInto(out *ContainerAppStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ContainerEnvironment ¶
type ContainerEnvironment struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec ContainerEnvironmentSpec `json:"spec,omitempty"`
Status ContainerEnvironmentStatus `json:"status,omitempty"`
}
ContainerEnvironment is the Schema for the containerenvironments API
func (*ContainerEnvironment) DeepCopy ¶
func (in *ContainerEnvironment) DeepCopy() *ContainerEnvironment
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ContainerEnvironment.
func (*ContainerEnvironment) DeepCopyInto ¶
func (in *ContainerEnvironment) DeepCopyInto(out *ContainerEnvironment)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ContainerEnvironment) DeepCopyObject ¶
func (in *ContainerEnvironment) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type ContainerEnvironmentList ¶
type ContainerEnvironmentList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []ContainerEnvironment `json:"items"`
}
ContainerEnvironmentList contains a list of ContainerEnvironment
func (*ContainerEnvironmentList) DeepCopy ¶
func (in *ContainerEnvironmentList) DeepCopy() *ContainerEnvironmentList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ContainerEnvironmentList.
func (*ContainerEnvironmentList) DeepCopyInto ¶
func (in *ContainerEnvironmentList) DeepCopyInto(out *ContainerEnvironmentList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ContainerEnvironmentList) DeepCopyObject ¶
func (in *ContainerEnvironmentList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type ContainerEnvironmentSpec ¶
type ContainerEnvironmentSpec struct {
// Foo is an example field of ContainerEnvironment. Edit containerenvironment_types.go to remove/update
Name string `json:"name,omitempty"`
Location string `json:"location,omitempty"`
}
ContainerEnvironmentSpec defines the desired state of ContainerEnvironment
func (*ContainerEnvironmentSpec) DeepCopy ¶
func (in *ContainerEnvironmentSpec) DeepCopy() *ContainerEnvironmentSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ContainerEnvironmentSpec.
func (*ContainerEnvironmentSpec) DeepCopyInto ¶
func (in *ContainerEnvironmentSpec) DeepCopyInto(out *ContainerEnvironmentSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ContainerEnvironmentStatus ¶
type ContainerEnvironmentStatus struct {
// INSERT ADDITIONAL STATUS FIELD - define observed state of cluster
// Important: Run "make" to regenerate code after modifying this file
EnvironmentID string `json:"environmentID,omitempty"`
EnvironmentName string `json:"environmentName,omitempty"`
EnvironmentIP string `json:"environmentIP,omitempty"`
EnvironmentStatus string `json:"environmentStatus,omitempty"`
EnvironmentFQDN string `json:"environemntFQDN,omitempty"`
}
ContainerEnvironmentStatus defines the observed state of ContainerEnvironment
func (*ContainerEnvironmentStatus) DeepCopy ¶
func (in *ContainerEnvironmentStatus) DeepCopy() *ContainerEnvironmentStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ContainerEnvironmentStatus.
func (*ContainerEnvironmentStatus) DeepCopyInto ¶
func (in *ContainerEnvironmentStatus) DeepCopyInto(out *ContainerEnvironmentStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ContainersTemplate ¶
type ContainersTemplate struct {
Name string `json:"name"`
Image string `json:"image"`
Args *[]string `json:"args"`
Resources *ContainersTemplateResources `json:"resources,omitempty"`
}
ContainersTemplate defines the desired state of Container inside a ContainerApp
func (*ContainersTemplate) DeepCopy ¶
func (in *ContainersTemplate) DeepCopy() *ContainersTemplate
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ContainersTemplate.
func (*ContainersTemplate) DeepCopyInto ¶
func (in *ContainersTemplate) DeepCopyInto(out *ContainersTemplate)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ContainersTemplateResources ¶
ContainersTemplateResources defines the desired state of resources inside a ContainerTemplate
func (*ContainersTemplateResources) DeepCopy ¶
func (in *ContainersTemplateResources) DeepCopy() *ContainersTemplateResources
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ContainersTemplateResources.
func (*ContainersTemplateResources) DeepCopyInto ¶
func (in *ContainersTemplateResources) DeepCopyInto(out *ContainersTemplateResources)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.